@@ -225,10 +225,12 @@ class Factory:
         return kwargs
 
     def get_instance(self, service_builder, service_name, instance_name, args=[], kwargs={}):
-        if ((self.key_new in kwargs) and kwargs[self.key_new]) or not(instance_name in self.__services[service_name]):
-            kwargs = self.delete_from_kwargs(kwargs)
-            inst = service_builder(*args, **kwargs)
-            self.__services[service_name][instance_name] = inst
+        if (self.key_new in kwargs) and (not kwargs[self.key_new]) and (instance_name in self.__services[service_name]):
+            return self.__services[service_name][instance_name]
+        #if ((self.key_new in kwargs) and kwargs[self.key_new]) or not(instance_name in self.__services[service_name]):
+        kwargs = self.delete_from_kwargs(kwargs)
+        inst = service_builder(*args, **kwargs)
+        self.__services[service_name][instance_name] = inst
         return self.__services[service_name][instance_name]
 
     def vault_client(self, url: str, token: str) -> hvac.Client:
