@@ -13,13 +13,15 @@ class SecurityStructure:
         self.tenants_str = " ".join(self.tenants)
 
 class VerifySecurity:
-    def __init__(self, logger, do_auth=None, factory=None):
+    def __init__(self, logger, factory, do_auth=None, scope_rules=None):
         self.logger = logger
-        if factory is not None:
-            consul = factory.consul(new=True)
-            self.do_auth = json.loads(consul.kv.get("services/auth-api/do_auth"))["do"]
+        consul = factory.consul(new=True)
+        self.do_auth = json.loads(consul.kv.get("services/auth-api/do_auth"))["do"]
+        self.scope_rules = json.loads(consul.kv.get("services/auth-api/scopes"))
         if do_auth is not None:
             self.do_auth = do_auth
+        if scope_rules is not None:
+            self.scope_rules = scope_rules
 
     async def verify_security(self, scopes: SecurityScopes, request: Request, tenant_id: str = Path("")): #user_scopes: Optional[str] = Header([], alias="user_scopes")
         try:
@@ -49,6 +51,19 @@ class VerifySecurity:
             raise HTTPException(status_code=status.HTTP_500_INTERNAL_SERVER_ERROR, detail=traceback.format_exc())
         return SecurityStructure(intersection_scopes, intersection_tenants)
 
+    async def _get_scopes_from_path(self, sec_scopes: SecurityScopes, request: Request):
+        method = request.method
+        pth = sec_scopes.scopes[0]
+        full_pth = f"{method} {pth}"
+        # self.logger.info(f'full_pth = {full_pth}')
+        scopes = self.scope_rules.get(full_pth, [])
+        # self.logger.info(f'scopes = {scopes}')
+        return SecurityScopes(scopes)
+
+    async def verify_scopes_from_path(self, sec_scopes: SecurityScopes, request: Request):
+        scopes = await self._get_scopes_from_path(sec_scopes, request)
+        return await self.verify_scopes(scopes, request)
+
     async def verify_scopes(self, sec_scopes: SecurityScopes, request: Request):
         try:
             if self.do_auth != 'yes':
